pub fn cost_http_request(request_size: u64, max_res_bytes: u64) -> u128Expand description
Gets the cycle cost of the Management canister method http_request.
pub fn cost_http_request(request_size: u64, max_res_bytes: u64) -> u128Gets the cycle cost of the Management canister method http_request.